#!/bin/bash

RUN=${0%/*}/
EXT1=$1
EXT2=$2
LANG=$3

#PART_DIR=".cache/"
PART_DIR="output/"
SOURCES=$PART_DIR
SVG_DIR=$SOURCES
OUTPUT="calendar.$EXT2"

# Make sure our pot is up to date
POT_FILE="po/guide.pot"
NEW_SVG=`ls -tr ${SOURCES}*-*.svg | tail -1`
if [ "$POT_FILE" -ot "$NEW_SVG" ]; then
  echo "[BUILD] $POT_FILE"
  xml2po -m svg -o - ${SOURCES}*-*.svg | ${RUN}exclude-pot.py > $POT_FILE
fi

# Build languages.
if [ $LANG ]; then
  PO_FILE="po/$LANG.po"
  # Refuse to generate a lnag that doesn't exist
  if [ ! -f $PO_FILE ]; then
    echo "Can't find language $LANG in $PO_FILE."
    exit 1
  fi
  # Make sure the po file it up to date
  if [ $PO_FILE -ot $POT_FILE ]; then
    echo "[BUILD] $PO_FILE"
    TEMP=".tmp.$LANG"
    msgmerge -o $TEMP $PO_FILE $POT_FILE &> .merge.log
    mv $TEMP $PO_FILE
    msgfmt -cv $PO_FILE
    rm messages.mo
  fi
  # Make sure our build files are language specific
  SVG_DIR="$PART_DIR$LANG/"
  ${RUN}make-lang.sh $SVG_DIR $PO_FILE $SOURCES
  if [ ! -d $SVG_DIR ]; then
    echo "[ERROR] $SVG_DIR"
    exit 1
  fi
  OUTPUT="ask-smart-questions.$LANG.$EXT2"
  PART_DIR=$SVG_DIR
fi

# This directory will contain all the pdf pages (not the final)
if [ ! -d $PART_DIR ]; then
 mkdir -p $PART_DIR
else
# I think V this might fix a bug.
#elif `ls ${PART_DIR}*-*.$EXT1`
  # If the directory does exist, then we need to be
  # Sure there aren't any legacy files hanging around.
  for PART_PATH in ${PART_DIR}*-*.$EXT1
    do
     PART_FILE=${PART_PATH##*/}
     # Look for pdf or png files in the part-way dir
     # Which don't exist in the source.
     SVG_FILE="$SVG_DIR${PART_FILE%.*}.svg"
     if [ ! -f "$SVG_FILE" ]; then
         echo "[DELTE] $PART_PATH"
         rm "$PART_PATH"
     fi
    done
fi

BUILD=false

# Generate one pdf file per svg
for SVG_PATH in ${SVG_DIR}*-*.svg
 do
  SVG_FILE=${SVG_PATH##*/}
  SVG_NAME=${SVG_FILE%.*}
  SVG_TEMP="$SVG_PATH.tmp"
  FILE="$PART_DIR$SVG_NAME.$EXT1"
  if [ "$FILE" -ot "$SVG_PATH" -a ! -f "$SVG_TEMP" ]; then
    echo "[BUILD] $FILE"
    if [ $EXT1 == 'pdf' ]; then
      inkscape -A $FILE $SVG_PATH &> .build_log
    elif [ $EXT1 == 'png' ]; then
      inkscape -e $FILE $SVG_PATH &> .build_log
    fi
    BUILD=true
  else
    echo "[-SKIP] $FILE"
    touch "$FILE"
  fi
  rm "$SVG_TEMP" &> /dev/null
done

if [ $OUTPUT -ot $PART_DIR -o $BUILD == true ]; then
  echo "[BUILD] $OUTPUT (Sub: $BUILD)"
  if [ -a $OUTPUT ]; then
    rm $OUTPUT
  fi
  if [ $EXT2 == 'pdf' ]; then
    pdftk ${PART_DIR}*.pdf output $OUTPUT &> .compile_log
  elif [ $EXT2 == 'tar.gz' ]; then
    HOME=$PWD
    cd "$PART_DIR"
    tar cvzf "$HOME/$OUTPUT" *.$EXT1 &> "$HOME/.compile_log"
    cd "$HOME"
  fi
else
  echo "[-SKIP] $OUTPUT"
fi

