#!/bin/bash

SVG_DIR=$1
PO_FILE=$2
SOURCES=$3
OLD_PWD=$PWD

# Make new svg files based on language
if [ -a $PO_FILE ]; then
 if [ ! -d $SVG_DIR ]; then
  mkdir -p $SVG_DIR
 else
   # Delete any old files not in the source.
    for SVG_DEST in ${SVG_DIR}*-*.svg
     do
     SVG_SOURCE="$SOURCES${SVG_DEST##*/}"
     if [ ! -f $SVG_SOURCE ]; then
         echo "[DELTE] $SVG_DEST"
         rm "$SVG_DEST"
     fi
   done
 fi

 # Start building required translations.
 for SVG_SOURCE in ${SOURCES}*-*.svg
  do
     SVG_DEST=$SVG_DIR${SVG_SOURCE##*/}
     if [ $SVG_DEST -ot $PO_FILE -o $SVG_DEST -ot $SVG_SOURCE ]; then
       xml2po -p $PO_FILE -o $SVG_DEST.tmp $SVG_SOURCE
       # This little mechanism makes sure that the svg file is different
       # This stops wasteful time spent on pdf generation on non-changed svgs
       SVG_TEMP="${SVG_DEST}.tmp"
       if diff -q "$SVG_DEST" "$SVG_TEMP" &> /dev/null; then
           # Update the time date stamp so we don't translate again
           touch "$SVG_DEST"
           echo "[IGNOR] $SVG_DEST"
       else
           # Actually use the build we've got.
           mv "$SVG_TEMP" "$SVG_DEST"
           echo "[BUILD] $SVG_DEST"
       fi
       # Keep the tmp file for the final format generator,
       # It will mean: "I didn't update the file"
       #rm "$SVG_TEMP"
     else
       echo "[-SKIP] $SVG_DEST"
     fi
 done
fi

